@@ -6,7 +6,7 @@ knitr::opts_chunk$set(
   eval = curl::has_internet()
 )
 
-## ---- eval=FALSE--------------------------------------------------------------
+## ----eval=FALSE---------------------------------------------------------------
 #  # from CRAN
 #  install.packages("stats19")
 #  # you can install the latest development (discoraged) using:
@@ -15,47 +15,47 @@ knitr::opts_chunk$set(
 ## -----------------------------------------------------------------------------
 library(stats19)
 
-## ----dl2017-accidents---------------------------------------------------------
-dl_stats19(year = 2017, type = "accident", ask = FALSE)
+## ----dl2022-accidents---------------------------------------------------------
+dl_stats19(year = 2022, type = "collision", ask = FALSE)
 
 ## -----------------------------------------------------------------------------
 stats19::file_names$DigitalBreathTestData2013.zip
 
-## ----dl2017-all, eval=FALSE---------------------------------------------------
-#  dl_stats19(year = 2017)
+## ----dl2022-all, eval=FALSE---------------------------------------------------
+#  dl_stats19(year = 2022)
 
-## ----dl2017-read--------------------------------------------------------------
-crashes_2017_raw = get_stats19(year = 2017, type = "acc", format = FALSE)
+## ----dl2022-read--------------------------------------------------------------
+crashes_2022_raw = get_stats19(year = 2022, type = "collision", format = FALSE)
 
-## ---- echo=FALSE--------------------------------------------------------------
+## ----echo=FALSE---------------------------------------------------------------
 # skip vignettes if resource unavailable
-if(object.size(crashes_2017_raw) < 1000) {
+if(object.size(crashes_2022_raw) < 1000) {
   knitr::opts_chunk$set(eval = FALSE)
 }
 
-## ----crashes2017-class--------------------------------------------------------
-class(crashes_2017_raw)
-dim(crashes_2017_raw)
+## ----crashes2022-class--------------------------------------------------------
+class(crashes_2022_raw)
+dim(crashes_2022_raw)
 
-## ----read2017-raw-format------------------------------------------------------
-crashes_2017_raw = read_accidents(year = 2017, format = FALSE)
-crashes_2017 = format_accidents(crashes_2017_raw)
-nrow(crashes_2017_raw)
-ncol(crashes_2017_raw)
-nrow(crashes_2017)
-ncol(crashes_2017)
+## ----read2022-raw-format------------------------------------------------------
+crashes_2022_raw = read_collisions(year = 2022, format = FALSE)
+crashes_2022 = format_collisions(crashes_2022_raw)
+nrow(crashes_2022_raw)
+ncol(crashes_2022_raw)
+nrow(crashes_2022)
+ncol(crashes_2022)
 
-## ----crashes2017-columns------------------------------------------------------
-crashes_2017_raw[c(7, 18, 23, 25)]
-crashes_2017[c(7, 18, 23, 25)]
+## ----crashes2022-columns------------------------------------------------------
+crashes_2022_raw[c(7, 18, 23, 25)]
+crashes_2022[c(7, 18, 23, 25)]
 
-## ---- echo=FALSE, eval=FALSE--------------------------------------------------
+## ----echo=FALSE, eval=FALSE---------------------------------------------------
 #  # commented out as confusing...
 #  key_patt = "severity|speed|light|human"
-#  key_vars = grep(key_patt, x = names(crashes_2017_raw), ignore.case = TRUE)
-#  random_n = sample(x = nrow(crashes_2017_raw), size = 3)
-#  crashes_2017_raw[random_n, key_vars]
-#  crashes_2017[random_n, key_vars]
+#  key_vars = grep(key_patt, x = names(crashes_2022_raw), ignore.case = TRUE)
+#  random_n = sample(x = nrow(crashes_2022_raw), size = 3)
+#  crashes_2022_raw[random_n, key_vars]
+#  crashes_2022[random_n, key_vars]
 
 ## ----variables-and-schema-----------------------------------------------------
 stats19_variables
@@ -65,16 +65,16 @@ stats19_schema
 format_column_names(stats19_variables$variable[1:3])
 
 ## ----format-main--------------------------------------------------------------
-crashes_2017 = format_accidents(crashes_2017_raw)
+crashes_2022 = format_collisions(crashes_2022_raw)
 
-# vehicle data for 2017
-dl_stats19(year = 2017, type = "vehicle", ask = FALSE)
-vehicles_2017_raw = read_vehicles(year = 2017)
-vehicles_2017 = format_vehicles(vehicles_2017_raw)
+# vehicle data for 2022
+dl_stats19(year = 2022, type = "vehicle", ask = FALSE)
+vehicles_2022_raw = read_vehicles(year = 2022)
+vehicles_2022 = format_vehicles(vehicles_2022_raw)
 
-# casualties data for 2017
-dl_stats19(year = 2017, type = "casualty", ask = FALSE)
-casualties_2017 = read_casualties(year = 2017)
+# casualties data for 2022
+dl_stats19(year = 2022, type = "casualty", ask = FALSE)
+casualties_2022 = read_casualties(year = 2022)
 
 ## ----summarise-stats19--------------------------------------------------------
 summarise_stats19 = function(x) {
@@ -89,62 +89,62 @@ summarise_stats19 = function(x) {
 }
 
 ## ----summarise-crashes--------------------------------------------------------
-knitr::kable(summarise_stats19(crashes_2017), 
+knitr::kable(summarise_stats19(crashes_2022), 
              caption = "Summary of formatted crash data.")
 
 ## ----summarise-vehicles-------------------------------------------------------
-knitr::kable(summarise_stats19(vehicles_2017), 
+knitr::kable(summarise_stats19(vehicles_2022), 
              caption = "Summary of formatted vehicles data.")
 
 ## ----summarise-casualties-----------------------------------------------------
-knitr::kable(summarise_stats19(casualties_2017), 
+knitr::kable(summarise_stats19(casualties_2022), 
              caption = "Summary of formatted casualty data.")
 
-## ---- echo=FALSE, results='asis'----------------------------------------------
+## ----echo=FALSE, results='asis'-----------------------------------------------
 key_patt = "severity|speed|light|human"
 key_vars = grep(key_patt, x = names(stats19::accidents_sample_raw), ignore.case = TRUE)
 knitr::kable(stats19::accidents_sample_raw[, key_vars])
 
-## ----2017-cas-----------------------------------------------------------------
-dl_stats19(year = 2017, type = "casualty", ask = FALSE)
-casualties_2017 = read_casualties(year = 2017)
-nrow(casualties_2017)
-ncol(casualties_2017)
+## ----2022-cas-----------------------------------------------------------------
+dl_stats19(year = 2022, type = "casualty", ask = FALSE)
+casualties_2022 = read_casualties(year = 2022)
+nrow(casualties_2022)
+ncol(casualties_2022)
 
-## ----2017-cas-columns---------------------------------------------------------
-casualties_2017[c(4, 5, 6, 14)]
+## ----2022-cas-columns---------------------------------------------------------
+casualties_2022[c(4, 5, 6, 14)]
 
-## ----2017-cas-columns-all-----------------------------------------------------
-names(casualties_2017)
+## ----2022-cas-columns-all-----------------------------------------------------
+names(casualties_2022)
 
-## ----dl2017-vehicles----------------------------------------------------------
-dl_stats19(year = 2017, type = "vehicle", ask = FALSE)
-vehicles_2017 = read_vehicles(year = 2017)
-nrow(vehicles_2017)
-ncol(vehicles_2017)
+## ----dl2022-vehicles----------------------------------------------------------
+dl_stats19(year = 2022, type = "vehicle", ask = FALSE)
+vehicles_2022 = read_vehicles(year = 2022)
+nrow(vehicles_2022)
+ncol(vehicles_2022)
 
-## ----2017-veh-columns---------------------------------------------------------
-vehicles_2017[c(3, 14:16)]
+## ----2022-veh-columns---------------------------------------------------------
+vehicles_2022[c(3, 14:16)]
 
-## ----2017-veh-columns-all-----------------------------------------------------
-names(vehicles_2017)
+## ----2022-veh-columns-all-----------------------------------------------------
+names(vehicles_2022)
 
-## ---- eval=FALSE, echo=FALSE--------------------------------------------------
+## ----eval=FALSE, echo=FALSE---------------------------------------------------
 #  # old code to be up-dated
 #  d14 = "Stats19_Data_2005-2014"
-#  crashes_2005_2014 = read_accidents(data_dir = d14)
+#  crashes_2005_2014 = read_collisions(data_dir = d14)
 #  crashes_2005_2014_f = format_stats19_2005_2014_ac(crashes_2005_2014)
 #  d15 = "RoadSafetyData_2015"
-#  crashes_2015 = read_accidents(data_dir = d15, filename = "Accidents_2015.csv")
+#  crashes_2015 = read_collisions(data_dir = d15, filename = "Accidents_2015.csv")
 #  crashes_2015_f = format_stats19_2015_ac(crashes_2015)
 #  d16 = "dftRoadSafety_Accidents_2016"
-#  crashes_2016 = read_accidents(data_dir = d16, filename = "dftRoadSafety_Accidents_2016.csv")
+#  crashes_2016 = read_collisions(data_dir = d16, filename = "dftRoadSafety_Accidents_2016.csv")
 #  crashes_2016_f = format_stats19_2016_ac(crashes_2016)
-#  all_crashes = rbind(crashes_2015_f, crashes_2016_f, crashes_2017_f)
+#  all_crashes = rbind(crashes_2015_f, crashes_2016_f, crashes_2022_f)
 #  table(ac$Accident_Severity)
 
 ## ----format-crashes-sf--------------------------------------------------------
-crashes_sf = format_sf(crashes_2017)
+crashes_sf = format_sf(crashes_2022)
 
 ## ----nfatalities--------------------------------------------------------------
 library(sf)
@@ -167,8 +167,8 @@ nrow(crashes_wy)
 ## ----table-join, message = FALSE----------------------------------------------
 library(tidyr)
 library(dplyr)
-sel = casualties_2017$accident_index %in% crashes_wy$accident_index
-casualties_wy = casualties_2017[sel, ]
+sel = casualties_2022$accident_index %in% crashes_wy$accident_index
+casualties_wy = casualties_2022[sel, ]
 cas_types = casualties_wy %>% 
   select(accident_index, casualty_type) %>% 
   group_by(accident_index) %>% 
@@ -183,7 +183,7 @@ cj = left_join(crashes_wy, cas_types)
 ## ----table-join-examples------------------------------------------------------
 base::setdiff(names(cj), names(crashes_wy))
 
-## ---- out.width="90%", fig.show='hold'----------------------------------------
+## ----out.width="90%", fig.show='hold'-----------------------------------------
 plot(
   cj[cj$cycling > 0, "speed_limit", ],
   cex = cj$Total[cj$cycling > 0] / 3,
@@ -195,7 +195,7 @@ plot(
   main = "Speed limit (passenger)"
   )
 
-## ---- echo=FALSE--------------------------------------------------------------
+## ----echo=FALSE---------------------------------------------------------------
 knitr::include_graphics("wy-overview.jpg")
 
 ## ----sfplot, fig.show='hold', out.width="100%", fig.cap="Spatial distribution of serious and fatal crashes in West Yorkshire, for cycling, walking, being a car passenger and other modes of travel. Colour is related to the speed limit where the crash happened (red is faster) and size is proportional to the total number of people hurt in each crash (legend not shown).", fig.width=9, fig.height=7----
